import Vue from "vue";
import store from "@/store/index";
import router from "@/router";
import i18n from "@/libs/i18n";

export default function middleware({ to, next }) {
    const loginRoutes = [
        "login",
        "signup",
        "forgot-password",
        "reset-password",
        "validate-email",
        "verify-email",
    ];
    const indexRoutes = ["home", "start-now", "policy", "policy-agencies", "policy-companies", "terms-and-conditions", "terms-and-conditions-agencies", "terms-and-conditions-companies", "404"];
    const loginData = Vue.$cookies.get("login-data", { parseJSON: true });
    if (loginData) {
        if (!indexRoutes.includes(to.name)) {
            if (to.params.role && loginData.account_type === to.params.role) {
                if (loginData.remember_me) {
                    const date = Date.now();
                    if (loginData.exp_date <= date) {
                        store
                            .dispatch("refreshToken", loginData.refresh_token)
                            .then(() => {
                                if (loginRoutes.includes(to.name)) {
                                    return next({
                                        name: "dashboard",
                                        params: {
                                            lang: i18n.locale,
                                            role: loginData.account_type,
                                        },
                                    });
                                }
                                return next();
                            });
                    } else {
                        if (loginRoutes.includes(to.name)) {
                            return next({
                                name: "dashboard",
                                params: {
                                    lang: i18n.locale,
                                    role: loginData.account_type,
                                },
                            });
                        }
                        return next();
                    }
                } else {
                    if (loginRoutes.includes(to.name)) {
                        return next({
                            name: "dashboard",
                            params: {
                                lang: i18n.locale,
                                role: loginData.account_type,
                            },
                        });
                    }
                    return next();
                }
            } else {
                if (to.name) {
                    return next({
                        name: to.name,
                        params: {
                            lang: i18n.locale,
                            role: loginData.account_type,
                        },
                    });
                }
                return next({
                    name: "dashboard",
                    params: { lang: i18n.locale, role: loginData.account_type },
                });
            }
        }
        return next();
    }
    if (!loginRoutes.includes(to.name) && !indexRoutes.includes(to.name)) {
        return next({ name: "login", params: { lang: i18n.locale } });
    }
    return next();
}
