import i18n from "@/libs/i18n";
import middleware from "../../middleware";
import middlewareAccountState from "../../middlewareAccountState";
export default [

    {
        path: "signup",
        name: "signup",
        component: () => import("@/views/pages/authentication/Signup.vue"),
        meta: {
            middleware,
            layout: "full",
            resource: "Auth",
            redirectIfLoggedIn: true,
            authImage: "auth-icon-icon",
        },
    },
    {
        path: "complete-registration",
        name: "CompleteRegistration",
        component: () => import("@/views/pages/authentication/CompleteRegistration.vue"),
        meta: {
            middleware,
            layout: "full",
            resource: "Auth",
            redirectIfLoggedIn: true,
            authImage: "auth-icon-icon",
        },
    },
    {
        path: "update-data-registration",
        name: "UpdateDataRegistration",
        component: () => import("@/views/pages/authentication/UpdateDataRegistration.vue"),
        meta: {
            middleware,
            layout: "full",
            resource: "Auth",
            redirectIfLoggedIn: true,
            authImage: "auth-icon-icon",
        },
    },
    {
        path: "login",
        name: "login",
        component: () => import("@/views/pages/authentication/Login.vue"),
        meta: {
            middleware,
            layout: "auth",
            resource: "Auth",
            redirectIfLoggedIn: true,
            authImage: "auth-icon-icon",
        },
    },
    {
        path: "forgot-password",
        name: "forgot-password",
        component: () => import("@/views/pages/authentication/ForgotPassword.vue"),
        meta: {
            middleware,
            layout: "auth",
            resource: "Auth",
            redirectIfLoggedIn: true,
            authImage: "auth-icon-icon",
        },
    },
    {
        path: "reset-password/:token",
        name: "reset-password",
        component: () => import("@/views/pages/authentication/ResetPassword.vue"),
        meta: {
            middleware,
            layout: "auth",
            resource: "Auth",
            redirectIfLoggedIn: true,
            authImage: "auth-icon-icon",
        },
    },
    {
        path: "validate-email",
        name: "validate-email",
        component: () => import("@/views/pages/authentication/ValidateEmail.vue"),
        meta: {
            middleware,
            layout: "auth",
            resource: "Auth",
            redirectIfLoggedIn: true,
            authImage: "auth-icon-icon",
        },
    },
    {
        path: "verify-email",
        name: "verify-email",
        component: () => import("@/views/pages/authentication/VerifyEmail.vue"),
        meta: {
            middleware,
            layout: "auth",
            resource: "Auth",
            redirectIfLoggedIn: true,
            authImage: "auth-icon-icon",
            noBackButton: true,
        },
    },
    {
        path: ":role",
        component: {
            render(c) {
                return c("router-view");
            },
        },
        meta: {
            middleware: middlewareAccountState,
        },
        children: [
            {
                path: "settings",
                component: {
                    render(c) {
                        return c("router-view");
                    },
                },
                children: [
                    {
                        path: "",
                        name: "settings",
                        component: () => import("@/views/pages/settings/settings.vue"),
                        meta: {
                            middleware: [middleware, middlewareAccountState],
                        },
                    },
                    {
                        path: "account-information",
                        name: "account-information",
                        component: () => import(
                                "@/views/pages/settings/account-details.vue"
                            ),
                        meta: {
                            middleware: [middleware, middlewareAccountState],
                        },
                    },
                ],
            },
            {
                path: "payment-successfully/:id",
                name: "paymentSuccessfully",
                component: () => import("@/views/pages/paymentSuccessfully.vue"),
                meta: {
                    middleware: [middleware, middlewareAccountState],
                    layout: "full",
                },
            },
            {
                path: "payment-error/:id",
                name: "paymentError",
                component: () => import("@/views/pages/paymentError.vue"),
                meta: {
                    middleware: [middleware, middlewareAccountState],
                    layout: "full",
                },
            },
        ],
    },
];
