import i18n from "@/libs/i18n";
import middleware from "../../middleware";
import middlewareAccountState from "../../middlewareAccountState";
export default [
    {
        path: ":role",
        // path: 'business',
        component: {
            render(c) {
                return c("router-view");
            },
        },
        meta: {
            middleware: middlewareAccountState,
        },
        children: [
            {
                path: "dashboard",
                name: "dashboard",
                component: () =>
                    import(
                        "@/views/pages/employeesSeekers/dashboard/dashboard.vue"
                    ),
                meta: {
                    middleware: [middleware, middlewareAccountState],
                },
            },
            {
                path: "notification",
                name: "notification",
                component: () =>
                    import(
                        "@/views/pages/employeesSeekers/dashboard/notification.vue"
                    ),
                meta: {
                    middleware: [middleware, middlewareAccountState],
                },
            },
            {
                path: "orders",
                component: {
                    render(c) {
                        return c("router-view");
                    },
                },

                children: [
                    {
                        path: "",
                        name: "orders",
                        component: () =>
                            import(
                                "@/views/pages/employeesSeekers/orders/index.vue"
                            ),
                        meta: {
                            middleware: [middleware, middlewareAccountState],
                        },
                    },
                    {
                        path: "list",
                        component: {
                            render(c) {
                                return c("router-view");
                            },
                        },

                        children: [
                            {
                                path: "",
                                name: "orders-list",
                                component: () =>
                                    import(
                                        "@/views/pages/employeesSeekers/orders/list.vue"
                                    ),
                                meta: {
                                    middleware: [
                                        middleware,
                                        middlewareAccountState,
                                    ],
                                },
                            },
                            {
                                path: ":id",
                                component: {
                                    render(c) {
                                        return c("router-view");
                                    },
                                },
                                children: [
                                    {
                                        path: "",
                                        name: "orders-list-details",

                                        component: () =>
                                            import(
                                                "@/views/pages/employeesSeekers/orders/orderDetails.vue"
                                            ),
                                        meta: {
                                            middleware: [
                                                middleware,
                                                middlewareAccountState,
                                            ],
                                        },
                                    },
                                    {
                                        path: "offers",
                                        name: "orders-list-details-offers",

                                        component: () =>
                                            import(
                                                "@/views/pages/employeesSeekers/orders/offersForOrder.vue"
                                            ),
                                        meta: {
                                            middleware: [
                                                middleware,
                                                middlewareAccountState,
                                            ],
                                        },
                                    },
                                ],
                            },
                        ],
                    },
                    {
                        path: "offers",
                        component: {
                            render(c) {
                                return c("router-view");
                            },
                        },
                        children: [
                            {
                                path: "",
                                name: "orders-offers",
                                component: () =>
                                    import(
                                        "@/views/pages/employeesSeekers/orders/offers.vue"
                                    ),
                                meta: {
                                    middleware: [
                                        middleware,
                                        middlewareAccountState,
                                    ],
                                },
                            },
                            {
                                path: ":id",
                                name: "orders-offers-details",
                                component: () =>
                                    import(
                                        "@/views/pages/employeesSeekers/orders/offerDetails.vue"
                                    ),
                                meta: {
                                    middleware: [
                                        middleware,
                                        middlewareAccountState,
                                    ],
                                },
                            },
                        ],
                    },
                    {
                        path: "add",
                        name: "orders-order-add",
                        component: () =>
                            import(
                                "@/views/pages/employeesSeekers/orders/AddOrder.vue"
                            ),
                        meta: {
                            middleware: [middleware, middlewareAccountState],
                        },
                    },
                    {
                        path: "edit/:id",
                        name: "orders-order-edit",
                        component: () =>
                            import(
                                "@/views/pages/employeesSeekers/orders/EditOrder.vue"
                            ),
                        meta: {
                            middleware: [middleware, middlewareAccountState],
                        },
                    },
                ],
            },
            {
                path: "projects",
                component: {
                    render(c) {
                        return c("router-view");
                    },
                },
                children: [
                    {
                        path: "",
                        name: "projects",
                        component: () =>
                            import(
                                "@/views/pages/employeesSeekers/projects/index.vue"
                            ),
                        meta: {
                            middleware: [middleware, middlewareAccountState],
                        },
                    },
                    {
                        path: ":id",
                        component: {
                            render(c) {
                                return c("router-view");
                            },
                        },

                        children: [
                            {
                                path: "",
                                name: "project-details",
                                component: () =>
                                    import(
                                        "@/views/pages/employeesSeekers/projects/details.vue"
                                    ),
                                meta: {
                                    middleware: [
                                        middleware,
                                        middlewareAccountState,
                                    ],
                                },
                            },
                            {
                                path: "offers",
                                name: "offers-for-project",
                                component: () =>
                                    import(
                                        "@/views/pages/employeesSeekers/projects/offersForProject.vue"
                                    ),
                                meta: {
                                    middleware: [
                                        middleware,
                                        middlewareAccountState,
                                    ],
                                },
                            },
                        ],
                    },
                    {
                        path: "employer",
                        component: {
                            render(c) {
                                return c("router-view");
                            },
                        },
                        children: [
                            {
                                path: ":id",
                                name: "project-employer",
                                component: () =>
                                    import(
                                        "@/views/pages/users/employeeDetails.vue"
                                    ),
                                meta: {
                                    middleware: [
                                        middleware,
                                        middlewareAccountState,
                                    ],
                                },
                            },
                        ],
                    },
                ],
            },
            {
                path: "financial",
                component: {
                    render(c) {
                        return c("router-view");
                    },
                },

                children: [
                    {
                        path: "",
                        name: "financial",
                        component: () =>
                            import(
                                "@/views/pages/employeesSeekers/financial/index.vue"
                            ),
                        meta: {
                            middleware: [middleware, middlewareAccountState],
                        },
                    },
                ],
            },
            {
                path: "reviews",
                component: {
                    render(c) {
                        return c("router-view");
                    },
                },

                children: [
                    {
                        path: "",
                        name: "reviews",
                        component: () =>
                            import(
                                "@/views/pages/employeesSeekers/reviews/index.vue"
                            ),
                        meta: {
                            middleware: [middleware, middlewareAccountState],
                        },
                    },
                ],
            },
        ],
    },
];
