export default {
    async loadBusinessOrders({ commit }, data) {
        commit("loadingStart", null);
        await this._vm.$http
            .get(
                `business/projects?page=${data.page}&per_page=${data.per_page}&status=${data.status}&industry_preference=${data.industry_preference}&order_by=${data.order_by}&search=${data.search}`
            )
            .then((respo) => {
                if (respo.status === 200) {
                    commit("setBusinessOrders", respo.data.data);
                    commit("loadingFinish");
                }
            })
            .catch((error) => {
                commit("loadingFinish");
                throw error;
            });
    },
    async loadBusinessOrdersDetails({ commit }, applicantsId) {
        commit("loadingStart", null);
        await this._vm.$http
            .get(`business/projects/${applicantsId}`)
            .then((respo) => {
                if (respo.status === 200) {
                    commit("setBusinessOrderDetails", respo.data.data.content);
                    commit("loadingFinish");
                }
            })
            .catch((error) => {
                commit("loadingFinish");
                throw error;
            });
    },
    async addBusinessOrder({ commit }, data) {
        commit("loadingStart", null);
        await this._vm.$http
            .post(`business/projects`, data)
            .then((respo) => {
                if (respo.status === 200) {
                    commit("setBusinessStoreOrder", respo.data.data.content);
                    commit("successMessage", "order_saved_successfully");
                    commit("loadingFinish");
                }
            })
            .catch((error) => {
                commit("loadingFinish");
                throw error;
            });
    },
    async editBusinessOrder({ commit }, data) {
        commit("loadingStart", null);
        await this._vm.$http
            .put(`business/projects/${data.id}`, data)
            .then((respo) => {
                if (respo.status === 200) {
                    commit("successMessage", "order_edit_successfully");
                    commit("loadingFinish");
                }
            })
            .catch((error) => {
                commit("loadingFinish");
                throw error;
            });
    },

    async deleteBusinessOrder({ commit }, id) {
        commit("loadingStart", null);
        await this._vm.$http
            .delete(`business/projects/${id}`)
            .then((respo) => {
                if (respo.status === 200) {
                    commit("successMessage", "order_delete_successfully");
                    commit("loadingFinish");
                }
            })
            .catch((error) => {
                commit("loadingFinish");
                throw error;
            });
    },

    async changeOrdersStatus({ commit }, data) {
        commit("loadingStart", null);
        await this._vm.$http
            .put(`business/projects/${data.id}/status`, data)
            .then((respo) => {
                if (respo.status === 200) {
                    if (respo.data.data) {
                        commit(
                            "setBusinessOrderDetails",
                            respo.data.data.content
                        );
                    }
                    commit(
                        "successMessage",
                        "change_orders_status_successfully"
                    );
                    commit("loadingFinish");
                }
            })
            .catch((error) => {
                commit("loadingFinish");
                throw error;
            });
    },
};
