import router from "@/router";

export default {
    async loadProfileInfo({ commit }, data) {
        let url = "";
        const loginData = this._vm.$cookies.get("login-data", {
            parseJSON: true,
        });

        if (loginData) {
            commit("loadingStart", null);
            if (loginData.account_type === "employee") {
                url = `employees/user/me`;
            } else if (loginData.account_type === "business") {
                url = `business/user/me`;
            }
            return await this._vm.$http
                .get(url)
                .then((respo) => {
                    if (respo.status === 200) {
                        commit("setProfileInfo", respo.data.data);
                        commit("loadingFinish");
                        return respo.data.data;
                    }
                })
                .catch((error) => {
                    commit("loadingFinish");
                    throw error;
                });
        }
    },
    async updateProfile({ commit }, data) {
        commit("loadingStart", null);
        let url = "";
        const loginData = this._vm.$cookies.get("login-data", {
            parseJSON: true,
        });
        if (loginData && loginData.account_type === "employee") {
            url = `employees/user/profile/update`;
        } else if (loginData && loginData.account_type === "business") {
            url = `business/user/profile/update`;
        }
        return await this._vm.$http
            .post(url, data)
            .then((respo) => {
                if (respo.status === 200) {
                    commit("successMessage", "update_profile_successfully");
                    commit("loadingFinish");
                }
            })
            .catch((error) => {
                commit("loadingFinish");
                throw error;
            });
    },

    async changePassword({ commit }, data) {
        commit("loadingStart", null);
        return await this._vm.$http
            .post("auth/password/change", data)
            .then((respo) => {
                if (respo.status === 200) {
                    commit("successMessage", "change_password_successfully");
                    commit("loadingFinish");
                }
            })
            .catch((error) => {
                commit("loadingFinish");
                throw error;
            });
    },

    async contractUpload({ commit }, data) {
        commit("loadingStart", null);
        return await this._vm.$http
            .post("business/user/contract/upload", data)
            .then((respo) => {
                if (respo.status === 200) {
                    commit("successMessage", "contract_upload_successfully");
                    commit("loadingFinish");
                }
            })
            .catch((error) => {
                commit("loadingFinish");
                throw error;
            });
    },

    async loadNotifications({ commit }, data) {
        let url = "";
        const loginData = this._vm.$cookies.get("login-data", {
            parseJSON: true,
        });
        if (loginData) {
            commit("loadingStart", null);
            if (loginData.account_type === "employee") {
                url = `employees/notifications`;
            } else if (loginData.account_type === "business") {
                url = `business/notifications`;
            }
            return await this._vm.$http
                .get(url)
                .then((respo) => {
                    if (respo.status === 200) {
                        commit("setNotifications", respo.data.data);
                        commit("loadingFinish");
                        return respo.data.data;
                    }
                })
                .catch((error) => {
                    commit("loadingFinish");
                    throw error;
                });
        }
    },
};
